@@ -12,6 +12,8 @@ from annotell.input_api.resources.input.cameras_sequence import CamerasSequence
 from annotell.input_api.resources.input.input import InputResource
 from annotell.input_api.resources.input.lidars_and_cameras import LidarsAndCameras
 from annotell.input_api.resources.input.lidars_and_cameras_sequence import LidarsAndCamerasSequence
+from annotell.input_api.resources.input.lidars import Lidars
+from annotell.input_api.resources.input.lidars_sequence import LidarsSequence
 from annotell.input_api.resources.project.project import ProjectResource
 
 DEFAULT_HOST = "https://input.annotell.com"
@@ -27,8 +29,8 @@ class InputApiClient:
                  host: str = DEFAULT_HOST,
                  auth_host: str = DEFAULT_AUTH_HOST,
                  client_organization_id: int = None,
-                 max_upload_retry_attempts: int = 23,
-                 max_upload_retry_wait_time: int = 60):
+                 max_retry_attempts: int = 23,
+                 max_retry_wait_time: int = 60):
         """
         :param auth: auth credentials, see https://github.com/annotell/annotell-python/tree/master/annotell-auth
         :param host: override for input api url
@@ -42,8 +44,8 @@ class InputApiClient:
                                   host=host,
                                   auth_host=auth_host,
                                   client_organization_id=client_organization_id)
-        self._file_client = FileResourceClient(max_upload_retry_attempts=max_upload_retry_attempts,
-                                               max_upload_retry_wait_time=max_upload_retry_wait_time)
+        self._file_client = FileResourceClient(max_retry_attempts=max_retry_attempts,
+                                               max_retry_wait_time=max_retry_wait_time)
 
         self.calibration = CalibrationResource(self._client)
         self.project = ProjectResource(self._client)
@@ -54,3 +56,5 @@ class InputApiClient:
         self.lidars_and_cameras_sequence = LidarsAndCamerasSequence(self._client, self._file_client)
         self.cameras = Cameras(self._client, self._file_client)
         self.cameras_sequence = CamerasSequence(self._client, self._file_client)
+        self.lidars = Lidars(self._client, self._file_client)
+        self.lidars_sequence = LidarsSequence(self._client, self._file_client)
