@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import List, Dict, Optional
+from typing import Dict
 
 from annotell.input_api.model.calibration import Position, RotationQuaternion
 
